Skip to contents

Returns a character vector representing a line break.

Usage

createLogLine(start = "#", middle = "-", times = 10, end = start)

Arguments

start

character vector, the starting string of the line break

middle

character vector, the middle part of the line break

times

integer vector, the number of times to repeat the middle string

end

character vector, the string ending the line break

Value

A character string obtained by pasting together start, middle, and end. If times is provided, the middle string is replicated.

Author

Alessandro Barberis

Examples

createLogLine()
#> [1] "#----------#"