Returns a character vector representing a line break.
Arguments
- start
character vector, the starting string of the line break
- middle
character vector, the middle part of the line break
- times
integer vector, the number of times to repeat the
middlestring- end
character vector, the string ending the line break